/*******************************************************************************
 * Copyright (c) 2012, 2013 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.utility;

import java.io.PrintWriter;

/**
 * An exception handler that prints the exceptions to the configured
 * {@link PrintWriter}.
 */
public class PrintWriterExceptionHandler
	extends ExceptionHandlerAdapter
{
	private final PrintWriter printWriter;

	/**
	 * Construct an exception handler that prints any exceptions
	 * to the specified print writer.
	 */
	public PrintWriterExceptionHandler(PrintWriter printWriter) {
		super();
		if (printWriter == null) {
			throw new NullPointerException();
		}
		this.printWriter = printWriter;
	}

	@Override
	public void handleException(Throwable t) {
		t.printStackTrace(this.printWriter);
	}
}